@@ -41,14 +41,17 @@ class Schroot(object):
         else:
             directory = '/'
 
-        cmd = Schroot.MyPopen([
+        cmd = [
             SCHROOT_BIN,
             '-d', directory,
             '-r',
-            '-c', self.__session,
-            '--' ] + list(args)
-        )
-        return cmd
+            '-c', self.__session
+        ]
+
+        if 'user' in kwargs:
+           cmd += ['-u', kwargs['user']]
+
+        return Schroot.MyPopen(cmd + ['--'] + list(args))
 
     def __del__(self):
         if not self.__session:
